@@ -10,7 +10,7 @@ import yaml.representer
 import yaml.resolver
 import yaml.scanner
 import yaml.serializer
-from dezimal import Dec
+from dezimal import Dezimal
 
 
 class Resolver(yaml.resolver.BaseResolver):
@@ -44,7 +44,7 @@ class Loader(yaml.reader.Reader, yaml.scanner.Scanner, yaml.parser.Parser,
 
 def dec_constructor(loader, node):
     value = loader.construct_scalar(node)
-    return Dec(value)
+    return Dezimal(value)
 
 
 yaml.add_constructor('!dec', dec_constructor, Loader)
@@ -120,6 +120,11 @@ for func in aws_cloudformation_intrinsic_functions:
 
 class Dumper(yaml.Dumper):
 
+    def __init__(self, **kwargs):
+        if 'sort_keys' not in kwargs:
+            kwargs['sort_keys'] = False
+        super().__init__(**kwargs)
+
     def represent_str(self, data):
         if '\n' in data:
             return self.represent_scalar('tag:yaml.org,2002:str', data, style='|')
@@ -138,7 +143,7 @@ class Dumper(yaml.Dumper):
         return True
 
 
-yaml.add_representer(Dec, Dumper.represent_dec, Dumper=Dumper)
+yaml.add_representer(Dezimal, Dumper.represent_dec, Dumper=Dumper)
 yaml.add_representer(str, Dumper.represent_str, Dumper=Dumper)
 
 
